/***************************************************************************
                          pppstatus.c  -  description
                             -------------------
    begin                : Mar 13 1999
    copyright            : (C) 2000 by Gabriel Montenegro
    email                : johnpetrucci@users.sourceforge.net
 
 ***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,  *
 *  USA.                                                                   *
 *                                                                         *
 ***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <time.h>
#include <ctype.h>
#include <curses.h>

#include <sys/wait.h>
#include <sys/stat.h>
#include <sys/param.h>
#include <sys/ioctl.h>

#include <arpa/inet.h>

#include <net/ppp_defs.h>
#include <net/if.h> 
#include <net/if_ppp.h>
#include <netinet/in.h>

#include "pppstatus.h"


/*-----------------------------------------------------------------------*
 *  IP_ADDRESS - Gets local IP address                                   *
 *-----------------------------------------------------------------------*/

void ip_address(void)
{
   struct ifreq ifr;
   struct sockaddr_in *skt;
   
   strcpy(ifr.ifr_name, interface);
   
   if(ioctl(ppp_s, SIOCGIFADDR, &ifr) < 0);

   skt = (struct sockaddr_in*)&ifr.ifr_addr;
   
   if(skt->sin_addr.s_addr)
     stats.ip_addr_rtrn =  inet_ntoa(skt->sin_addr);
   else
    stats.ip_addr_rtrn = "Unknown";
   
   mvprintw(17, 22, "%s", stats.ip_addr_rtrn);
   
}
/*-----------------------------------------------------------------------*
 *  CHECK_EMAIL - Check for new emails                                   *
 *-----------------------------------------------------------------------*/

void check_email(void)
{
   FILE *email_box;
   int rtrn = 0;
   char location[128], buf[128];
   
   sprintf(location, MAIL_PATH "%s", stats.user_box);
   
   if(!stat(location, &st))
     rtrn = st.st_size; 
   stats.email = 0;
   
   if(rtrn){
      if((email_box = fopen(location, "r"))) 
	{
	   while(!feof(email_box))
	     {
		fgets(buf, 128, email_box);
		if(!strncmp(buf, "From ", 5))
		  stats.email++; 
	     }
	   chcolor(1,0);
	   if(stats.email < 10)
	     mvprintw(17, 64, "0%d         ", stats.email);
	   else
	     mvprintw(17, 64, "%d           ", stats.email);
	   fclose(email_box);
	}
      else
	mvprintw(17, 64, "Can't check");
   }
   else
     mvprintw(17, 64, "00         ");
}

/*-----------------------------------------------------------------------*
 *  GET_STATISTICS - Gets RX/TX Packets, Bytes and Errors                *
 *-----------------------------------------------------------------------*/
int get_stat(void)
{
   struct ppp_stats ppp_cur;
   static int ppp_opened = 0;
   if (!ppp_opened) { /* If not opened yet... Open the PPP device */
      memset(&ppp_cur, 0, sizeof(ppp_cur));
      if ((ppp_s = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
	return -1;
      ppp_opened = 1;
   }
   get_ppp_stats(&ppp_cur); /* Update the information */
   stats.tx_packets = ppp_cur.p.ppp_opackets;
   stats.rx_packets = ppp_cur.p.ppp_ipackets;   
   stats.rx_bytes = ppp_cur.p.ppp_ibytes;
   stats.tx_bytes = ppp_cur.p.ppp_obytes;
   stats.rx_errors = ppp_cur.p.ppp_ierrors;
   stats.tx_errors = ppp_cur.p.ppp_oerrors;
   return(0);
   
}

void get_ppp_stats(struct ppp_stats *cur) {
   
   struct ifpppstatsreq req;
   memset(&req, 0, sizeof(req));  
   req.stats_ptr = (char *)&req.stats;
  
   strcpy(req.ifr__name, interface);
   if (ioctl(ppp_s, SIOCGPPPSTATS, &req) >= 0)
      *cur = req.stats;
}



/*-----------------------------------------------------------------------*
 * LOG - Put in a file the connection specs                              *
 *-----------------------------------------------------------------------*/

int log(int quit)
{
   FILE *log_file;
   time_t off;
   char buf[256], logfile[128];
   int exists = 0;
   sprintf(logfile, "%s/" LOG_FILENAME, home);
   off = time(NULL);
   
   if(!(log_file = fopen(logfile, "a+"))) {
      close_ppps("PPPStatus can not write the information of connection on log file"
		 "\n\nPPPStatus v" VERSION " - " AUTHOR "\n\n");
   }   
   rewind(log_file);
   while(fgets(buf, sizeof(buf), log_file))
     if(strstr(buf, "PPPStatus v " VERSION))
       exists = 1;
   if(!exists)
     fprintf(log_file, "PPPStatus v " VERSION " LOG file\n\n");
   
   if(!stats.online_hour && !stats.online_min && !stats.online_sec)
      return fclose(log_file);
   
   fprintf(log_file, ". : .\n\n");
   fprintf(log_file, "Connection Started at : %s", ctime(&stats.connect_time));
   if(quit)
     fprintf(log_file, "PPPStatus Exited at   : %s", ctime(&off));
   else
     fprintf(log_file, "Connection Finished at: %s", ctime(&off));
   if(stats.online_days)
     fprintf(log_file, "Connected Time: %d day(s) %d hour(s) %d minute(s) and %d second(s)\n\n", stats.online_days, stats.online_hour, stats.online_min, stats.online_sec);
   else
     fprintf(log_file, "Connected Time:  %d hour(s) %d minute(s) and %d second(s)\n\n", stats.online_hour, stats.online_min, stats.online_sec);
   fprintf(log_file, "Transmition Information\n");
   fprintf(log_file, "TX Packets: %ld    ", stats.tx_packets);
   fprintf(log_file, "TX Bytes: %.0f    ", stats.tx_bytes);
   fprintf(log_file, "TX Errors: %ld\n", stats.tx_errors);
   fprintf(log_file, "Total Receive Information\n");
   fprintf(log_file, "RX Packets: %ld    ", stats.rx_packets);
   fprintf(log_file, "RX Bytes: %.0f    ", stats.rx_bytes);
   fprintf(log_file, "RX Errors: %ld\n\n", stats.rx_errors);
   if(quit)
     {
	fprintf(log_file, "(*) PPPStatus still with connection active (user quits PPPStatus).\n\n");
	fprintf(stdout, "Saving logfile... DONE!\n\n");
     }
 return fclose(log_file);
} 

/*-----------------------------------------------------------------------*
 * GET_TIME - Get the online time                                        *
 *-----------------------------------------------------------------------*/
void get_time(void)
{
   long x;
   stats.current_time = time(NULL); /* Get the current time */
   if(!stat(var_run_pid, &st)) 
     stats.connect_time = st.st_mtime; /* Get the time that PPP run */
   x = stats.current_time - stats.connect_time; /* Online Time in secs */
   stats.online_sec = x % 60;
   stats.online_min = (x / 60) % 60; 
   stats.online_hour = (x / 3600) % 24;
   stats.online_days = (x / (3600 * 24)) % 365;
}

/*-----------------------------------------------------------------------*
 *  IS_ONLINE - Check if the connection is active                        *
 *-----------------------------------------------------------------------*/
int is_online(void)
{
   int rtrn = 0;
   char check[128], red[256];
   FILE *routefile;
   
   if(!stat(var_run_pid, &st))
     {
	if(st.st_size)
	  {
	     if(online)
	       return 1;
	     else if((routefile = fopen(PATH_PROC_NET_ROUTE, "r")) == NULL)
	       {
		  sprintf(red, "Error! Unable to open %s\n"
			  "Check in your Kernel Configuration if /proc filesystem"
			  " is supported\n\n", PATH_PROC_NET_ROUTE);
		  close_ppps(red);
	       }
	     while(fgets(check, 128, routefile))
	       if(strstr(check, interface)){
		  online = rtrn = 1;
		  break;
	       }
	     fclose(routefile);	     
	  }
	else
	  rtrn = 0;
     }
   /* LED POWER ON/OFF */
   if(rtrn) {
      if(!con){
	 chcolor(3,1); move(12, 10); hline(CHAR,3);
	 con = 1; discon = 0;
	 refresh();
      }
   }
   else{
      if(!discon) {
	 chcolor(2,0); move(12, 10); hline(CHAR, 3);
	 discon = 1; con = 0; online = 0; disconnected = 1;
	 refresh();
	 log(0);
      }
   }
   return rtrn;
}

   
/*-----------------------------------------------------------------------*
 * UPDATE_INFO - Puts TX/RX Packets, Bytes, Erros on the screen          * 
 *-----------------------------------------------------------------------*/
void update_info(void)
{
   chcolor(1,0);
   mvprintw(19, 64, "%ld", stats.online_days);
   mvprintw(19, 28, "%d:%02d:%02d ", stats.online_hour, stats.online_min, stats.online_sec);
   mvprintw(20, 28, "%ld", stats.rx_packets);
   mvprintw(20, 64, "%ld", stats.tx_packets);
   mvprintw(22, 28, "%ld", stats.rx_errors);
   mvprintw(22, 64, "%ld", stats.tx_errors);
   mvprintw(21, 28, "%.0f", stats.rx_bytes);
   mvprintw(21, 64, "%.0f", stats.tx_bytes);
}

/*-------------------------------------------------------------------------*
 * CLEAR_INFO - Clear TX/RX Packets, Bytes, Erros...                       *
 *-------------------------------------------------------------------------*/
void clear_info(void)
{
   chcolor(5,0);
   mvprintw(19, 63, "   ");
   mvprintw(19, 30, "          ");
   mvprintw(20, 30, "          ");
   mvprintw(20, 63, "          ");
   mvprintw(22, 30, "          ");
   mvprintw(22, 63, "          ");
   mvprintw(21, 30, "          ");
   mvprintw(21, 63, "          ");
   mvprintw(17, 22, "               ");
}


/*-----------------------------------------------------------------------*
 *  LOAD_OPTIONS - Open and read options in a file                       *
 *-----------------------------------------------------------------------*/
int load_options(void)
{
   FILE *optfile;
   char cfgfile[128], temp[256], real[256], get[256];
   int a, b, value=0;
   sprintf(cfgfile, "%s/" RC_FILENAME, home);
   if( !(optfile = fopen(cfgfile, "r") ) )
     {
        fprintf(stderr, "\nUnable to read options in %s file.\n"
                "Maybe this is your first time running PPPStatus\n"
                "PPPStatus will try to save the configuration file...\n", cfgfile);

        if(!(optfile=fopen(cfgfile, "w")))
          {
             fprintf(stderr, "PPPStatus tried to write default configurations without success...\n"
		     "Check if you have free space in your hard disk\n\n");
             exit(0);
          }  
        fprintf(optfile, "# PPPStatus v" VERSION " Configuration file - Gabriel Montenegro\n"
                "# Please, leave interface, speed, high_contrast and video untouched (lowcase)\n\n"
                "interface = ppp0         # ppp0, ppp1, ...\n"
                "speed = 33.6             # 14.4, 28.8, 33.6, 56, 115.2\n"
                "video = vga              # vga, mono\n"
                "high_contrast = no       # yes, no\n"
                "#user_email = root        # Check user email\n"
		"# End Of Configuration File");
        fclose(optfile);
        fprintf(stderr, "Success!\n\n"
		"If you wanna change the default configurations, \n"
		"edit %s/.pppstatus.rc file.\n\n", home);
        optfile = fopen(cfgfile, "r");
     }
   while(!feof(optfile))
     {
        fgets(temp, sizeof(temp), optfile);
	for(a = 0; a < strlen(temp)-1; a++)
	switch(temp[a])
	  {
	   case '\t':
             real[a] = '\0';
	     break;
	   case '#':
	     value++;
             real[a] = '\0';
	     break;
	   default:
	     if(!value)
	        real[a] = temp[a];
	  }	
	  value = 0;
        if(strstr(real, "interface") || strstr(real, "speed")
           || strstr(real, "high_contrast") || strstr(real, "video")
	   || strstr(real, "user_email"))
          {
             b=0;
             bzero(get, strlen(get));
             for(a = 0; a <= strlen(real)-1; a++)
               if(real[a] == '=') {
                  while(real[a+1] != '\0')
                    {
                       if(real[a+1] != ' ')
                         get[b] = real[a+1];
                       else
                         b--;
                       b++; a++;
                    }
                  get[b] = '\0';
                  break;
               }
             if(strstr(real, "interface"))
               {
                  interface = malloc(sizeof(char));
		  for(a = 0; a <= 100; a++)
                    {
                       sprintf(temp, "ppp%i", a);
                       if(strstr(temp, get))
                         {
                            sprintf(interface, "%s", get);
                            sprintf(var_run_pid, "/var/run/%s.pid", interface);
			    break;
                         }
		       
                    }
                  if(strcmp(interface, get))
                    {
                       fprintf(stderr, "\nPPPStatus v0.2 - Gabriel Montenegro\n\n"
                               "%s contains an invalid interface name (%s).\n\n", RC_FILENAME, get);
                       exit(0);
                    }
               }
             else if(strstr(real, "video"))
               {
                  if(!strcmp(get, "vga"))
                    VGA = 1;
                  else if(!strcmp(get, "mono"))
                    VGA = 0;
                  else
		    {
		       fprintf(stderr, "\nPPPStatus v0.2 - Gabriel Montenegro\n\n"
			       "%s file contains a false value (%s) in tab \"video\"\n\n", RC_FILENAME, get);
		       exit(0);
		    }
	       }
             else if(strstr(real, "speed"))
               {
                  if(!strcmp(get, "14.4") || !strcmp(get, "28.8") ||
                     !strcmp(get, "33.6") || !strcmp(get, "56") ||
                     !strcmp(get, "115.2")) {
		       SPEED = atof(get);
		  }
                  else
                    {
                       fprintf(stdout, "\nPPPStatus v0.2 - Gabriel Montenegro\n\n"
                               "%s file contains a speed that PPPStatus do not support : %s\n\n", RC_FILENAME, get);
                       exit(0);
                    }
               }
             else if(strstr(real, "high_contrast"))
               {
                  if(!strcmp(get, "yes"))
                    GRAPHIC_BRIGHT = 1;
                  else if(!strcmp(get, "no"))
                    GRAPHIC_BRIGHT = 0;
                  else
                    {
                       fprintf(stdout, "\nPPPStatus v0.2 - Gabriel Montenegro\n\n"
                               "%s file contains a false value (%s) in tab \"high_contrast\"\n\n", RC_FILENAME, get);
                       exit(0);
                    }
               }
	     else if(strstr(real, "user_email"))
	       {
		  strcpy(stats.user_box, get);
		  check = 1;
	       }
          }
     }
   return fclose(optfile);
}

/*-----------------------------------------------------------------------*
 *  LED_ON/OFF - Show the leds on the screen                             *
 *-----------------------------------------------------------------------*/
void led_on(unsigned int who)
{
   if(who == LED_RX){
      chcolor(3,1);
      move(12, 37); hline(CHAR, 2);
   }
   else if(who == LED_TX){
      chcolor(3,1); 
      move(12, 41); hline(CHAR, 2);
   }
}


void led_off(unsigned int who)
{
   if(who == LED_RX){
      chcolor(5,0);
      move(12, 37); hline(32, 2); /* 32 = SPACE */
   }
   else if(who == LED_TX){
      chcolor(5,0);
      move(12, 41); hline(32, 2); 
   }
}


/*-----------------------------------------------------------------------*
 *  UPDATE_STAT - Update The Graphical Statistic                         *
 *-----------------------------------------------------------------------*/
void update_stat(void)
{
   int x, y, cont = 0;
   long bps[2];
   float makegraph_in, makegraph_out, ks;
   
   /* Putting in the last hline the new statistic */
   
   
   if(!stats.rx_bytes_comp)
     stats.rx_bytes_comp = stats.rx_bytes;
   if(!stats.tx_bytes_comp)
     stats.tx_bytes_comp = stats.tx_bytes;
   
   bps[0] = (stats.rx_bytes - stats.rx_bytes_comp);
   bps[1] = (stats.tx_bytes - stats.tx_bytes_comp);
   
   /* ks variable gets the speed in k/s of the connection */
   ks = (float)(bps[0] + bps[1]);
   ks /= 1000;// ks /= 5;
   if(ks >= 0.0)
     mvprintw(15, 36, "%.2f Kb/s  ", ks);
   else
     mvprintw(15, 36, "0.00 Kb/s   ");
   
   stats.rx_bytes_comp = stats.rx_bytes;
   stats.tx_bytes_comp = stats.tx_bytes;
   
   /* makegraph variable gets the amplitude of line bar */
   
   makegraph_in = ((float)((bps[0] / SPEED) / 100) * 6);
  // makegraph_in /= 10;
   makegraph_out = ((float)((bps[1] / SPEED) / 100) * 6);
  // makegraph_out /= 10;
		   
   
   for(x = 0; x != 10; x++) {
      in[x].hline[75] = 0;
      out[x].hline[75] = 0;
   }
   
   if(makegraph_in > 10)
     makegraph_in = 10;
   if(makegraph_out > 10)
     makegraph_out = 10;
   
   for(x = 0; x < makegraph_in; x++)
     in[x].hline[75] = 1;
   for(x = 0; x < makegraph_out; x++)
     out[x].hline[75] = 1;
   
   /* Hnn... now I have to print the new statistic on the screen... */
   
   for(y = 0; y != 10; y++) {
      for(x = 0; x != 76; x++) { 
	 /* Move the graphic to left) */
	 if(x) {
	    in[y].hline[x-1] = in[y].hline[x];
	    out[y].hline[x-1] = out[y].hline[x];
	 }
	 
	 /* Print the graphic on screen */
	 if(in[y].hline[x] && out[y].hline[x]) /* If shline is TRUE... */
	   { 
	      chcolor(3, 0);
	      move((y+10)-(y+cont), x+2);
	      hline(CHAR, 1);
	   }
	 else if(in[y].hline[x] && !out[y].hline[x])
	   {
	      chcolor(3, 1);
	      move((y+10)-(y+cont), x+2);
	      hline(CHAR, 1);
	   }
	 else if(!in[y].hline[x] && out[y].hline[x])
	   {
	      chcolor(4, GRAPHIC_BRIGHT);
	      move((y+10)-(y+cont), x+2);
	      hline(CHAR, 1);
	   }
	 else
	   mvaddstr((y+10)-(y+cont), x+2, " ");
      }
      cont++;
   }
}
   

/*--------------------------------------------------------------------------*
 * SHOW_USAGE - Print the right usage on the screen                         *
 *--------------------------------------------------------------------------*/
void show_usage(char *name)
{
   fprintf(stderr, "\nPPPStatus v" VERSION " - " AUTHOR "\n"
	   "Usage:    %s [-i] [-v] [-s] [-b]\n" 
	   " -i\t-Interface-\t\tppp0, ppp1, ...\n"
	   " -v\t-  Video  -\t\tvga, mono.\n"
	   " -s\t-  Speed  -\t\t14.4, 28.8, 33.6, 56, 115.2\n"
	   " -b\t- Bright  -\t\tyes, no\n"
	   "Please, send bug reports to Gabriel Montenegro <johnpetrucci@users.sourceforge.net>\n\n", name);
}
/*--------------------------------------------------------------------------*
 *  CHCOLOR  -  Change the Color                                            *
 *--------------------------------------------------------------------------*/
void chcolor(int x, int y) {
   
   init_pair(1, COLOR_CYAN, COLOR_BLACK);
   init_pair(2, COLOR_RED, COLOR_BLACK);
   init_pair(3, COLOR_GREEN, COLOR_BLACK);
   init_pair(4, COLOR_YELLOW, COLOR_BLACK);
   init_pair(5, COLOR_BLACK, COLOR_BLACK);
   init_pair(6, COLOR_WHITE, COLOR_BLACK);
   init_pair(7, COLOR_GREEN, COLOR_GREEN);
   init_pair(8, COLOR_YELLOW, COLOR_YELLOW);
   init_pair(9, COLOR_RED, COLOR_RED);
   
   if(!y)
     attrset(COLOR_PAIR(x));
   if(y)
     attrset(COLOR_PAIR(x)|A_BOLD);
}

/*---------------------------------------------------------------------------*
 * CLOSE_PPPS                                                                *
 *---------------------------------------------------------------------------*/

void close_ppps(char *errmsg)
{
   endwin();
   curs_set(1);
   system("clear");
   fprintf(stderr, "%s", errmsg);
   exit(0);
}

/*---------------------------------------------------------------------------*
 *  FACE - Draw the face of the program                                      *
 *---------------------------------------------------------------------------*/
void face(void)
{ 
   chcolor(6,0);
   border(0, 0, 0, 0, 0, 0, 0, 0);
   mvprintw(17, 7,"IP Address:");
   if(check)
     mvprintw(17, 42, "New email(s):");
   mvprintw(19, 42,"Online Days:");
   mvprintw(19, 7, "Online Time:");
   mvprintw(20, 7, "Received Packets:");
   mvprintw(21, 7, "Bytes Received:");
   mvprintw(22, 7, "Errors on Receiving:");
   mvprintw(20, 42,"Transmited Packets:");
   mvprintw(21, 42,"Bytes Trasmited:");
   mvprintw(22, 42,"Errors on Trasmition:");
   mvprintw(13, 37,"RX");
   mvprintw(13, 41,"TX");
   mvprintw(18, 7,"Active Interface:");
   mvprintw(18, 42, "Graphic Using Speed:");
   mvprintw(13, 9, "ON/OFF"); 
   mvprintw(24, 7,".Author : Gabriel Montenegro <johnpetrucci@users.sourceforge.net>.");
   refresh();
   chcolor(6,1);
   mvprintw(00, 31,".PPPStatus v" VERSION ".");
   refresh();
   chcolor(1,0);
   mvprintw(18, 28, "%s", interface);
   mvprintw(18, 64, "%.1f Kb/s", SPEED);
   refresh();
}
 
/*--------------------------------------------------------------------------*
 *  M A I N - The head of the program                                       *
 *--------------------------------------------------------------------------*/
int main(int argc, char *argv[]) 
{  
   int x, y, key_pressed, first = 1;
   char *temp;
   fprintf(stderr, "Running PPPStatus v%s...", VERSION);
   strncpy(home, (temp = getenv("HOME")) != NULL ? temp : "(null)", sizeof(home));
   if(home == "/")
     strcpy(home, "");
   load_options();
   for(x = 1; x < argc; x++){
      char *a = argv[x];
      if(*a == '-')
	switch(a[1]) {
	 case 'i' : 
	   if(!(argv[x+1]) || (strlen(argv[x+1]) > 5) || strncmp(argv[x+1], "ppp", 3) || argv[x+1] == "ppp")
	     {
		show_usage(argv[0]);
		exit(0);
	     }
	   interface = argv[x+1]; 
	   strcpy(var_run_pid, "/var/run/");
	   strcat(var_run_pid, interface);
	   strcat(var_run_pid, ".pid");
	   break;
	 case 'v' :
	   if(!(argv[x+1]))
	     {
		show_usage(argv[0]);
		exit(0);
	     }
	   if(!strcmp(argv[x+1], "mono")) {
	      VGA = 0;
	      break;
	   }
	   if(!strcmp(argv[x+1], "vga")) {
	      VGA = 1;
	      break;
	   }
	   else
	     {
		show_usage(argv[0]);
		exit(0);
	     }
	   break;
	 case 's' :
	   if(!(argv[x+1]))
	     {
		show_usage(argv[0]);
		exit(0);
	     }
	   if(!strcmp(argv[x+1], "14.4") || !strcmp(argv[x+1], "28.8") ||
	      !strcmp(argv[x+1], "33.6") || !strcmp(argv[x+1], "56") ||
	      !strcmp(argv[x+1], "115.2"))
	     {
	      SPEED = atof(argv[x+1]);
	      break;
	     }
	   else
	     {
		show_usage(argv[0]);
		exit(0);
	     }
	 case 'b' :
	   if(!(argv[x+1]))
	     {
		show_usage(argv[0]);
		exit(0);
	     }
	   if(!(strcmp(argv[x+1], "yes")))
	     {
		GRAPHIC_BRIGHT = 1;
		break;
		  
	     }
	   if(!(strcmp(argv[x+1], "no")))
	     {
		GRAPHIC_BRIGHT = 0;
		break;
	     }
	   else { show_usage(argv[0]); exit(0); }
	 default:
	   show_usage(argv[0]);
	   exit(0);
	}
   
   }
   /* Initialize some info variables */
   stats.online_days = 0;
   stats.online_hour = 0; stats.online_min = 0; stats.online_sec = 0;
   stats.tx_packets = 0; stats.tx_bytes = 0; stats.tx_errors = 0;
   stats.rx_packets = 0; stats.rx_bytes = 0; stats.rx_errors = 0;
   stats.tx_bytes_comp = 0; stats.tx_bytes_comp = 0;
   
   printf("\e(U"); /* Thanks kspoon */
   initscr();
   intrflush(stdscr, FALSE);
   if(VGA)
     start_color();
   init_color(1, COLOR_RED, COLOR_GREEN, COLOR_BLUE);
   curs_set(0); /* Toggle the cursor off */ 
   nonl(); 
   noecho(); 
   cbreak(); 
   nodelay(stdscr, TRUE);
   face(); 
   update_info();
   if(check)
     check_email();
   while(1){ 
      if(is_online()) {
	 if(disconnected) {
	    clear_info();
	    for(y = 0; y != 10; y++)
	      for(x = 0; x != 75; x++)
	      {
		 in[y].hline[x] = 0;
		 out[y].hline[x] = 0;
	      }
	    stats.rx_bytes_comp = stats.tx_bytes_comp = stats.rx_packets_comp = stats.tx_packets_comp = 0;
	    update_stat();
	 }       
	 get_stat();
	 /* In case of a new RX Packet... the RX Led Turn on 
	  * Else... Turn off */
	 if(stats.rx_packets != stats.rx_packets_comp)
	   led_on(LED_RX);
	 else
	   led_off(LED_RX);
	 /* In case of a new TX Packet... the TX Led Turn on
	  * Else... Turn off */
	 if(stats.tx_packets != stats.tx_packets_comp)
	   led_on(LED_TX);
	 else
	   led_off(LED_TX);
	 
	 stats.rx_packets_comp = stats.rx_packets;
	 stats.tx_packets_comp = stats.tx_packets;
	 
	 get_time();
	 update_info();
	 
	 if((sec_value == 0 && first) || disconnected)
	   {
	      sec_value = stats.online_sec;
	      ip_address(); update_stat();
	      first = 0; disconnected = 0;
	   }
	 if(stats.online_sec == sec_value + 1 || 
	    (sec_value + 1) % 60 == stats.online_sec)
	   {
	      if(check)
		check_email();
	      update_stat();
	      sec_value = stats.online_sec;
	   }
	 usleep(10L); 
      }
      else
	usleep(100000L);
      
      key_pressed = getch();
      if(key_pressed != ERR && tolower(key_pressed) == 'q')
	break;
   }
   endwin();
   system("clear");
   curs_set(1);
   if(!disconnected)
     log(1);
   fprintf(stdout, "PPPStatus v" VERSION " - " AUTHOR "\n\n");
   return 0; 
}
